==> prestashop_1.4.0.2.zip: prestashop/modules/blockcms/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockcms}prestashop>blockcms_cd275312651aebf8cbbb8d3bb1c086ae'] = 'Bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_b27f7901b97d8beb6570e31b3bf06492'] = 'Añadir un bloque con varios links hacia sus CMS';
$_MODULE['<{blockcms}prestashop>blockcms_dd4b213d7d1c4c355c1e239d75510481'] = 'Configuración de los bloques CMS';
$_MODULE['<{blockcms}prestashop>blockcms_14666403912480ee81fa57bebd454d50'] = 'Añadir un nuevo bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_6e1ea63625a85f6d2d9ecbfb79586351'] = 'Lista de los bloques CMS de izquierda';
$_MODULE['<{blockcms}prestashop>blockcms_b718adec73e04ce3ec720dd11a06a308'] = 'ID';
$_MODULE['<{blockcms}prestashop>blockcms_12fa57039ef283136ca3ffd023ffa546'] = 'Nombre del bloque';
$_MODULE['<{blockcms}prestashop>blockcms_99121ab27aaa7472cfada9071c5ba434'] = 'Nombre de la categoría CMS';
$_MODULE['<{blockcms}prestashop>blockcms_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{blockcms}prestashop>blockcms_06df33001c1d7187fdd81ea1f5b277aa'] = 'Acciones ';
$_MODULE['<{blockcms}prestashop>blockcms_08a38277b0309070706f6652eeae9a53'] = 'Bajar';
$_MODULE['<{blockcms}prestashop>blockcms_258f49887ef8d14ac268c92b02503aaa'] = 'Subir';
$_MODULE['<{blockcms}prestashop>blockcms_7dce122004969d56ae2e0245cb754d35'] = 'Editar';
$_MODULE['<{blockcms}prestashop>blockcms_f2a6c498fb90ee345d997f888fce3b18'] = 'Borrar';
$_MODULE['<{blockcms}prestashop>blockcms_8f08c1af47e3e9611289c1882befc3a8'] = 'No existe ningún bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_0a40c06f34e5c794a7f0d3085d17d63a'] = 'Lista de los bloques CMS de la derecha';
$_MODULE['<{blockcms}prestashop>blockcms_965be994da393e5aa15bd3a2444c6ccf'] = 'Configuración de los links CMS a pie de página';
$_MODULE['<{blockcms}prestashop>blockcms_fab8ca8250236ed20b96f9750e1eacc7'] = 'Mostrar links a pie de página';
$_MODULE['<{blockcms}prestashop>blockcms_49ee3087348e8d44e1feda1917443987'] = 'Nombre';
$_MODULE['<{blockcms}prestashop>blockcms_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{blockcms}prestashop>blockcms_5aa1602194579edb6f91d7dd53eadb32'] = 'Nuevo bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_e83c1afa1d3dbe19fa9becebb5ca8480'] = 'Editar el bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_cbc7a9dd9af24ca8d066a4e595461baa'] = 'Nombre del bloque:';
$_MODULE['<{blockcms}prestashop>blockcms_b8889382c6efeb5e709043e4cda94941'] = 'Si deja el campo vacío, el nombre será el mismo que el de la categoría';
$_MODULE['<{blockcms}prestashop>blockcms_7310626b183e1bcfcc61b844e8ea3c5c'] = 'Elija una categoría CMS:';
$_MODULE['<{blockcms}prestashop>blockcms_be9469719aa6efa2fc3bd5768bc406d7'] = 'Ubicación';
$_MODULE['<{blockcms}prestashop>blockcms_945d5e233cf7d6240f6b783b36a374ff'] = 'Izquierda';
$_MODULE['<{blockcms}prestashop>blockcms_92b09c7c48c520c3c55e497875da437c'] = 'Derecha';
$_MODULE['<{blockcms}prestashop>blockcms_ea4788705e6873b424c65e91c2846b19'] = 'Volver';
$_MODULE['<{blockcms}prestashop>blockcms_903d12e7aa8c380c290b78c1898e01b7'] = 'Ubicación no válida';
$_MODULE['<{blockcms}prestashop>blockcms_f9dee1cf0e8efc87c4ce5bb1406f199e'] = 'Debe elegir al menos una página o subcategoría para crear un bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_5e75cbfbfd02a7b2fab0ed21505e811b'] = 'Página CMS o subcategoría no válidos';
$_MODULE['<{blockcms}prestashop>blockcms_420d575844f77db5299065080d9c237f'] = 'Nombre del bloque demasiado largo';
$_MODULE['<{blockcms}prestashop>blockcms_c12d11dfdaf316576221cf4319fbd7fc'] = 'id del bloque cms no válida';
$_MODULE['<{blockcms}prestashop>blockcms_05b51791a83d3cef29ad68b70d48d131'] = 'Activación footer no válida';
$_MODULE['<{blockcms}prestashop>blockcms_f6f21620d286e0f036f6382f14a2e7cf'] = 'Está tratando de suprimir un bloque cms que no existe';
$_MODULE['<{blockcms}prestashop>blockcms_dbbd04c612cb767a183d89c997597b77'] = 'Edición de links CMS a pie de página con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_e4ec6e33f436d248c7572b1f2909bac8'] = 'El bloque CMS se ha editado con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_99d619f5e241798571be9e64f1716ae5'] = 'Se ha editado con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_b30bb947efc48b2b38993417c289cedf'] = 'Se ha suprimido con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_be58fccb15fb119b8c3d485e3a8561c4'] = 'Configuración del bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_78edb384f1a71576034e00ed6844bcc2'] = 'No hay ningún CMS en esta categoría CMS';
$_MODULE['<{blockcms}prestashop>blockcms_34c869c542dee932ef8cd96d2f91cae6'] = 'Nuestras tiendas';
$_MODULE['<{blockcms}prestashop>blockcms_d1aa22a3126f04664e0fe3f598994014'] = 'Descuentos';
$_MODULE['<{blockcms}prestashop>blockcms_9ff0635f5737513b1a6f559ac2bff745'] = 'Nuevos productos';
$_MODULE['<{blockcms}prestashop>blockcms_3cb29f0ccc5fd220a97df89dafe46290'] = 'Mejores ventas';
$_MODULE['<{blockcms}prestashop>blockcms_02d4482d332e1aef3437cd61c9bcc624'] = 'Contacte con nosotros';
$_MODULE['<{blockcms}prestashop>blockcms_7a52e36bf4a1caa031c75a742fb9927a'] = 'Creado por';

==> prestashop_1.4.0.9.zip: prestashop/modules/blockcms/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockcms}prestashop>blockcms_cd275312651aebf8cbbb8d3bb1c086ae'] = 'Bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_b27f7901b97d8beb6570e31b3bf06492'] = 'Añadir un bloque con varios links hacia sus CMS';
$_MODULE['<{blockcms}prestashop>blockcms_dd4b213d7d1c4c355c1e239d75510481'] = 'Configuración de los bloques CMS';
$_MODULE['<{blockcms}prestashop>blockcms_14666403912480ee81fa57bebd454d50'] = 'Añadir un nuevo bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_6e1ea63625a85f6d2d9ecbfb79586351'] = 'Lista de los bloques CMS de izquierda';
$_MODULE['<{blockcms}prestashop>blockcms_b718adec73e04ce3ec720dd11a06a308'] = 'ID';
$_MODULE['<{blockcms}prestashop>blockcms_12fa57039ef283136ca3ffd023ffa546'] = 'Nombre del bloque';
$_MODULE['<{blockcms}prestashop>blockcms_99121ab27aaa7472cfada9071c5ba434'] = 'Nombre de la categoría CMS';
$_MODULE['<{blockcms}prestashop>blockcms_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{blockcms}prestashop>blockcms_06df33001c1d7187fdd81ea1f5b277aa'] = 'Acciones ';
$_MODULE['<{blockcms}prestashop>blockcms_08a38277b0309070706f6652eeae9a53'] = 'Bajar';
$_MODULE['<{blockcms}prestashop>blockcms_258f49887ef8d14ac268c92b02503aaa'] = 'Subir';
$_MODULE['<{blockcms}prestashop>blockcms_7dce122004969d56ae2e0245cb754d35'] = 'Editar';
$_MODULE['<{blockcms}prestashop>blockcms_f2a6c498fb90ee345d997f888fce3b18'] = 'Borrar';
$_MODULE['<{blockcms}prestashop>blockcms_8f08c1af47e3e9611289c1882befc3a8'] = 'No existe ningún bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_0a40c06f34e5c794a7f0d3085d17d63a'] = 'Lista de los bloques CMS de la derecha';
$_MODULE['<{blockcms}prestashop>blockcms_965be994da393e5aa15bd3a2444c6ccf'] = 'Configuración de los links CMS a pie de página';
$_MODULE['<{blockcms}prestashop>blockcms_fab8ca8250236ed20b96f9750e1eacc7'] = 'Mostrar links a pie de página';
$_MODULE['<{blockcms}prestashop>blockcms_49ee3087348e8d44e1feda1917443987'] = 'Nombre';
$_MODULE['<{blockcms}prestashop>blockcms_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{blockcms}prestashop>blockcms_5aa1602194579edb6f91d7dd53eadb32'] = 'Nuevo bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_e83c1afa1d3dbe19fa9becebb5ca8480'] = 'Editar el bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_cbc7a9dd9af24ca8d066a4e595461baa'] = 'Nombre del bloque:';
$_MODULE['<{blockcms}prestashop>blockcms_bdbaef442c586e1bbecb44eba1ba7e2d'] = 'Si deja el campo vacío, el nombre será el mismo que el de la categoría';
$_MODULE['<{blockcms}prestashop>blockcms_7310626b183e1bcfcc61b844e8ea3c5c'] = 'Elija una categoría CMS:';
$_MODULE['<{blockcms}prestashop>blockcms_be9469719aa6efa2fc3bd5768bc406d7'] = 'Ubicación';
$_MODULE['<{blockcms}prestashop>blockcms_945d5e233cf7d6240f6b783b36a374ff'] = 'Izquierda';
$_MODULE['<{blockcms}prestashop>blockcms_92b09c7c48c520c3c55e497875da437c'] = 'Derecha';
$_MODULE['<{blockcms}prestashop>blockcms_1acef6bfa7dc3360eed6bf44851fa6a4'] = 'Mostrar tiendas:';
$_MODULE['<{blockcms}prestashop>blockcms_93cba07454f06a4a960172bbd6e2a435'] = 'Sí';
$_MODULE['<{blockcms}prestashop>blockcms_bafd7322c6e97d25b6299b5d6fe8920b'] = 'No';
$_MODULE['<{blockcms}prestashop>blockcms_08f3899ad165f85f8596199966b8c673'] = 'Mostrar \"nuestras tiendas\" al final del bloque';
$_MODULE['<{blockcms}prestashop>blockcms_ea4788705e6873b424c65e91c2846b19'] = 'Volver';
$_MODULE['<{blockcms}prestashop>blockcms_671debf2ec0d4abe0faeb11270aea12d'] = 'Campo \"Mostrar la tienda\" no válido';
$_MODULE['<{blockcms}prestashop>blockcms_903d12e7aa8c380c290b78c1898e01b7'] = 'Ubicación no válida';
$_MODULE['<{blockcms}prestashop>blockcms_f9dee1cf0e8efc87c4ce5bb1406f199e'] = 'Debe elegir al menos una página o subcategoría para crear un bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_5e75cbfbfd02a7b2fab0ed21505e811b'] = 'Página CMS o subcategoría no válidos';
$_MODULE['<{blockcms}prestashop>blockcms_420d575844f77db5299065080d9c237f'] = 'Nombre del bloque demasiado largo';
$_MODULE['<{blockcms}prestashop>blockcms_c12d11dfdaf316576221cf4319fbd7fc'] = 'id del bloque cms no válida';
$_MODULE['<{blockcms}prestashop>blockcms_05b51791a83d3cef29ad68b70d48d131'] = 'Activación footer no válida';
$_MODULE['<{blockcms}prestashop>blockcms_f6f21620d286e0f036f6382f14a2e7cf'] = 'Está tratando de suprimir un bloque cms que no existe';
$_MODULE['<{blockcms}prestashop>blockcms_dbbd04c612cb767a183d89c997597b77'] = 'Edición de links CMS a pie de página con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_e4ec6e33f436d248c7572b1f2909bac8'] = 'El bloque CMS se ha editado con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_99d619f5e241798571be9e64f1716ae5'] = 'Se ha editado con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_b30bb947efc48b2b38993417c289cedf'] = 'Se ha suprimido con éxito';
$_MODULE['<{blockcms}prestashop>blockcms_be58fccb15fb119b8c3d485e3a8561c4'] = 'Configuración del bloque CMS';
$_MODULE['<{blockcms}prestashop>blockcms_78edb384f1a71576034e00ed6844bcc2'] = 'No hay ningún CMS en esta categoría CMS';
$_MODULE['<{blockcms}prestashop>blockcms_34c869c542dee932ef8cd96d2f91cae6'] = 'Nuestras tiendas';
$_MODULE['<{blockcms}prestashop>blockcms_d1aa22a3126f04664e0fe3f598994014'] = 'Descuentos';
$_MODULE['<{blockcms}prestashop>blockcms_9ff0635f5737513b1a6f559ac2bff745'] = 'Nuevos productos';
$_MODULE['<{blockcms}prestashop>blockcms_3cb29f0ccc5fd220a97df89dafe46290'] = 'Mejores ventas';
$_MODULE['<{blockcms}prestashop>blockcms_02d4482d332e1aef3437cd61c9bcc624'] = 'Contacte con nosotros';
$_MODULE['<{blockcms}prestashop>blockcms_7a52e36bf4a1caa031c75a742fb9927a'] = 'Creado por';
